@@ -334,6 +334,10 @@ func MergedGlobalWorkloadsCollection(
 	RemoteWorkloadInfosWithCluster := krt.NewManyCollection(
 		clusters,
 		func(ctx krt.HandlerContext, c *multicluster.Cluster) []krt.Collection[krt.ObjectWithCluster[model.WorkloadInfo]] {
+			opts := []krt.CollectionOption{
+				krt.WithDebugging(opts.Debugger()),
+				krt.WithStop(c.GetStop()),
+			}
 			endpointSlices := c.EndpointSlices()
 			pods := c.Pods()
 			waypointsPtr := krt.FetchOne(ctx, globalWaypoints, krt.FilterIndex(waypointsByCluster, c.ID))
@@ -386,14 +390,18 @@ func MergedGlobalWorkloadsCollection(
 			}
 
 			// Now we create everything anew
-			nodes := krt.MapCollection(clusteredNodes, unwrapObjectWithCluster, opts.WithName(fmt.Sprintf("NodeLocality[%s]", c.ID))...)
+			nodes := krt.MapCollection(clusteredNodes, unwrapObjectWithCluster, append(
+				opts,
+				krt.WithName(fmt.Sprintf("NodeLocality[%s]", c.ID)),
+			)...)
 
 			globalWorkloadServicesWithCluster := *workloadServicesPtr
 			globalWorkloadServices := krt.MapCollection(
 				globalWorkloadServicesWithCluster,
 				unwrapObjectWithCluster[model.ServiceInfo],
 				append(
-					opts.WithName(fmt.Sprintf("WorkloadServices[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("WorkloadServices[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -434,7 +442,8 @@ func MergedGlobalWorkloadsCollection(
 					flags,
 				),
 				append(
-					opts.WithName(fmt.Sprintf("PodWorkloads[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("PodWorkloads[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -444,7 +453,8 @@ func MergedGlobalWorkloadsCollection(
 				PodWorkloads,
 				wrapObjectWithCluster[model.WorkloadInfo](c.ID),
 				append(
-					opts.WithName(fmt.Sprintf("PodWorkloadsWithCluster[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("PodWorkloadsWithCluster[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -478,7 +488,8 @@ func MergedGlobalWorkloadsCollection(
 					flags,
 				),
 				append(
-					opts.WithName(fmt.Sprintf("WorkloadEntryWorkloads[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("WorkloadEntryWorkloads[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -488,7 +499,8 @@ func MergedGlobalWorkloadsCollection(
 				WorkloadEntryWorkloads,
 				wrapObjectWithCluster[model.WorkloadInfo](c.ID),
 				append(
-					opts.WithName(fmt.Sprintf("WorkloadEntryWorkloadsWithCluster[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("WorkloadEntryWorkloadsWithCluster[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -521,7 +533,8 @@ func MergedGlobalWorkloadsCollection(
 					flags,
 				),
 				append(
-					opts.WithName(fmt.Sprintf("ServiceEntryWorkloads[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("ServiceEntryWorkloads[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -531,7 +544,8 @@ func MergedGlobalWorkloadsCollection(
 				ServiceEntryWorkloads,
 				wrapObjectWithCluster[model.WorkloadInfo](c.ID),
 				append(
-					opts.WithName(fmt.Sprintf("ServiceEntryWorkloadsWithCluster[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("ServiceEntryWorkloadsWithCluster[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -561,7 +575,8 @@ func MergedGlobalWorkloadsCollection(
 					},
 				),
 				append(
-					opts.WithName(fmt.Sprintf("EndpointSliceWorkloads[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("EndpointSliceWorkloads[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -570,7 +585,8 @@ func MergedGlobalWorkloadsCollection(
 				EndpointSliceWorkloads,
 				wrapObjectWithCluster[model.WorkloadInfo](c.ID),
 				append(
-					opts.WithName(fmt.Sprintf("EndpointSliceWorkloadsWithCluster[%s]", c.ID)),
+					opts,
+					krt.WithName(fmt.Sprintf("EndpointSliceWorkloadsWithCluster[%s]", c.ID)),
 					krt.WithMetadata(krt.Metadata{
 						multicluster.ClusterKRTMetadataKey: c.ID,
 					}),
@@ -1385,14 +1401,25 @@ func constructServices(p *v1.Pod, services []model.ServiceInfo) map[string]*work
 			targetPort := port.TargetPort
 			// The svc.Ports represents the workloadapi.Service, which drops the port name info and just has numeric target Port.
 			// TargetPort can be 0 which indicates its a named port. Check if its a named port and replace with the real targetPort if so.
-			if named, f := svc.PortNames[int32(port.ServicePort)]; f && named.TargetPortName != "" {
-				// Pods only match on TargetPort names
-				tp, ok := FindPortName(p, named.TargetPortName)
-				if !ok {
-					// Port not present for this workload. Exclude the port entirely
-					continue
+			if named, f := svc.PortNames[int32(port.ServicePort)]; f {
+				if named.TargetPortName != "" {
+					// Kubernetes Service semantics: explicit named targetPort on the Service
+					// Pods only match on TargetPort names
+					tp, ok := FindPortName(p, named.TargetPortName)
+					if !ok {
+						// Port not present for this workload. Exclude the port entirely
+						continue
+					}
+					targetPort = uint32(tp)
+				} else if svc.Source.Kind == kind.ServiceEntry && named.PortName != "" {
+					// ServiceEntry semantics: no explicit named targetPort field; match by ServiceEntry port name to Pod container port name
+					if tp, ok := FindPortName(p, named.PortName); ok {
+						targetPort = uint32(tp)
+					} else if targetPort == 0 {
+						// Fallback to service port if we couldn't resolve a name and targetPort wasn't set
+						targetPort = port.ServicePort
+					}
 				}
-				targetPort = uint32(tp)
 			}
 
 			pl.Ports = append(pl.Ports, &workloadapi.Port{
